==> orcha-0.1.5b6.tar.gz: orcha-0.1.5b6/orcha/interfaces/__init__.py <==
#                                   MIT License
#
#              Copyright (c) 2021 Javier Alonso <jalonso@teldat.com>
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#      copies of the Software, and to permit persons to whom the Software is
#            furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
#                 copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#     AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#                                    SOFTWARE.
""":mod:`interfaces` defines the basic structure needed when communicating with Orcha"""
from .message import Message
from .petition import ActionCallbackT, EmptyPetition, P, Petition, ProcT
from .service import ServiceWrapper, register_service, start_service

__all__ = [
    "ActionCallbackT",
    "EmptyPetition",
    "Message",
    "P",
    "Petition",
    "ProcT",
    "register_service",
    "ServiceWrapper",
    "start_service",
]

==> orcha-0.1.10.tar.gz: orcha-0.1.10/orcha/interfaces/__init__.py <==
#                                   MIT License
#
#              Copyright (c) 2021 Javier Alonso <jalonso@teldat.com>
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#      copies of the Software, and to permit persons to whom the Software is
#            furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
#                 copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#     AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#                                    SOFTWARE.
""":mod:`interfaces` defines the basic structure needed when communicating with Orcha"""
from .message import Message
from .petition import (
    ActionCallbackT,
    EmptyPetition,
    P,
    Petition,
    ProcT,
    WatchdogPetition,
)
from .service import ServiceWrapper, register_service, start_service

__all__ = [
    "ActionCallbackT",
    "EmptyPetition",
    "Message",
    "P",
    "Petition",
    "ProcT",
    "register_service",
    "ServiceWrapper",
    "start_service",
    "WatchdogPetition",
]
